@@ -1,11 +1,11 @@
 package Selenium::UserAgent;
-$Selenium::UserAgent::VERSION = '0.09';
+$Selenium::UserAgent::VERSION = '0.10';
 # ABSTRACT: Emulate mobile devices by setting user agents when using webdriver
 use Moo;
 use JSON;
 use Cwd qw/abs_path/;
 use Carp qw/croak/;
-use List::Util qw/any/;
+use List::Util 1.33 qw/any/;
 use Selenium::Firefox::Profile;
 
 
@@ -241,7 +241,7 @@ Selenium::UserAgent - Emulate mobile devices by setting user agents when using w
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
